==> infra-4.2.0-sources.jar: com/liveperson/infra/network/http/request/HttpRequest.java <==
package com.liveperson.infra.network.http.request;


import android.util.Pair;

import com.liveperson.infra.ICallback;
import com.liveperson.infra.log.LPMobileLog;
import com.liveperson.infra.network.http.body.HttpRequestBody;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import okhttp3.Response;


/**
 * Created by ofira on 03/11/2015.
 */
public abstract class HttpRequest {

    private static final String TAG = HttpRequest.class.getSimpleName();
    private static final int DEFAULT_TIMEOUT = 30000;
    private int mTimeout = DEFAULT_TIMEOUT;
    private String mUrl;
    private HttpMethod mMethod;
    private boolean mFollowRedirect = true;
    private List<Pair<String, String>> mHeaders;
    protected HttpRequestBody mRequestBody;
    protected ICallback mCallback;
    private List<String> mCertificatePinningKeys;
    private static final String USER_AGENT = "User-Agent";
    private static final String ANDROID = "ANDROID";


    public enum HttpMethod {GET, HEAD, POST, PUT}

    public HttpRequest(String url, HttpMethod method) {
        mUrl = url;
        mMethod = method;
        mHeaders = new ArrayList<>();
        // adding a default User-Agent header with ANDROID
        mHeaders.add(Pair.create(USER_AGENT, ANDROID));
    }

    public void processResponse(Response response) {
        try {
            if (isResponseSuccessful(response)) {
                LPMobileLog.i(TAG, "onSuccess! " + response.code());
                if (mCallback != null) {
                    reportSuccess(response);
                }
            } else {
                LPMobileLog.i(TAG, "onResponseFailure " + response);
                if (mCallback != null) {
                    processErrorResponse(new Exception("On Response Error : " + (response == null ? "no Response" : " response code: " + response.code() + " body: " + response.body().string())));
//                    reportError("On Response Error : " + (response == null ? "no Response" : " response code: " + response.code() + " body: " + response.body().string()));
                }
            }

        } catch (IOException e) {
            processErrorResponse(e);
        }
    }

    protected boolean isResponseSuccessful(Response response) {
        return response != null && response.isSuccessful();
    }

    public void processErrorResponse(Exception e) {
        LPMobileLog.w(TAG, " Error while sending http request :" + (e != null ? " Error msg: " + e.getMessage() : ""));
        if (mCallback != null) {
            mCallback.onError(e);
        }
    }
//        String detailMessage = " Error while sending http request :" +
//                (e != null ? " Error msg: "  + e.getMessage(): "");
//        reportError(detailMessage);
//    }

//    protected void reportError(String detailMessage) {
//        if (mCallback != null) {
//            mCallback.onError(new Exception(detailMessage));
//        }
//    }

    protected void reportSuccess(Response response) throws IOException {
        mCallback.onSuccess(response == null ? "" : response.body().string());
    }

    public abstract HttpRequestBody getRequestBody();

	public abstract void setBody(HttpRequestBody body);

    // check if we are adding User-Agent header if so we want to set the already added default header to our new one. otherwise just add the header.
    public void addHeader(String name, String value) {
        if(name.equals(USER_AGENT)){
            mHeaders.set(0, Pair.create(USER_AGENT, value));
        } else {
            mHeaders.add(Pair.create(name, value));
        }
    }

    public List<Pair<String, String>> getHeaders() {
        return mHeaders;
    }

    public String getUrl() {
        return mUrl;
    }

    public void setUrl(String mUrl) {
        this.mUrl = mUrl;
    }

    public HttpMethod getMethod() {
        return mMethod;
    }

    public boolean getFollowRedirect() {
        return mFollowRedirect;
    }

    public List<String> getCertificatePinningKeys() {
        return mCertificatePinningKeys;
    }


    public void setFollowRedirect(boolean follow) {
        mFollowRedirect = follow;
    }

    public int getTimeout() {
        return mTimeout;
    }

    public void setTimeout(int timeout) {
        mTimeout = timeout;
    }

    public ICallback getCallback() {
        return mCallback;
    }

    public void setCertificatePinningKeys(List<String> certificatePinningKeys) {
        mCertificatePinningKeys = certificatePinningKeys;
    }

    public void setCallback(ICallback callback) {
        this.mCallback = callback;
    }


}

==> infra-4.3.0-sources.jar: com/liveperson/infra/network/http/request/HttpRequest.java <==
package com.liveperson.infra.network.http.request;


import android.util.Pair;

import com.liveperson.infra.ICallback;
import com.liveperson.infra.log.LPMobileLog;
import com.liveperson.infra.network.http.body.HttpRequestBody;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import okhttp3.Response;


/**
 * Created by ofira on 03/11/2015.
 */
public abstract class HttpRequest {

    private static final String TAG = HttpRequest.class.getSimpleName();
    private static final int DEFAULT_TIMEOUT = 30000;
    private int mTimeout = DEFAULT_TIMEOUT;
    private String mUrl;
    private HttpMethod mMethod;
    private boolean mFollowRedirect = true;
    private List<Pair<String, String>> mHeaders;
    protected HttpRequestBody mRequestBody;
    protected ICallback mCallback;
    private List<String> mCertificatePinningKeys;
    private static final String USER_AGENT = "User-Agent";
    private static final String ANDROID = "ANDROID";


    public enum HttpMethod {GET, HEAD, POST, PUT}

    public HttpRequest(String url, HttpMethod method) {
        mUrl = url;
        mMethod = method;
        mHeaders = new ArrayList<>();
        // adding a default User-Agent header with ANDROID
        mHeaders.add(Pair.create(USER_AGENT, ANDROID));
    }

    public void processResponse(Response response) {
        try {
            if (isResponseSuccessful(response)) {
                LPMobileLog.i(TAG, "onSuccess! " + response.code());
                if (mCallback != null) {
                    reportSuccess(response);
                }
            } else {
                LPMobileLog.i(TAG, "onResponseFailure " + response);
                if (mCallback != null) {
                    processErrorResponse(new Exception("On Response Error : " + (response == null ? "no Response" : " response code: " + response.code() + " body: " + response.body().string())));
//                    reportError("On Response Error : " + (response == null ? "no Response" : " response code: " + response.code() + " body: " + response.body().string()));
                }
            }

        } catch (IOException e) {
            processErrorResponse(e);
        }
    }

    protected boolean isResponseSuccessful(Response response) {
        return response != null && response.isSuccessful();
    }

    public void processErrorResponse(Exception e) {
        if (e != null) {
            LPMobileLog.w(TAG, " Error while sending http request : Error msg: " + e.getMessage(), e);
        } else {
            LPMobileLog.w(TAG, " Error while sending http request; no exception given");
        }

        if (mCallback != null) {
            mCallback.onError(e);
        }
    }
//        String detailMessage = " Error while sending http request :" +
//                (e != null ? " Error msg: "  + e.getMessage(): "");
//        reportError(detailMessage);
//    }

//    protected void reportError(String detailMessage) {
//        if (mCallback != null) {
//            mCallback.onError(new Exception(detailMessage));
//        }
//    }

    protected void reportSuccess(Response response) throws IOException {
        mCallback.onSuccess(response == null ? "" : response.body().string());
    }

    public abstract HttpRequestBody getRequestBody();

	public abstract void setBody(HttpRequestBody body);

    // check if we are adding User-Agent header if so we want to set the already added default header to our new one. otherwise just add the header.
    public void addHeader(String name, String value) {
        if(name.equals(USER_AGENT)){
            mHeaders.set(0, Pair.create(USER_AGENT, value));
        } else {
            mHeaders.add(Pair.create(name, value));
        }
    }

    public List<Pair<String, String>> getHeaders() {
        return mHeaders;
    }

    public String getUrl() {
        return mUrl;
    }

    public void setUrl(String mUrl) {
        this.mUrl = mUrl;
    }

    public HttpMethod getMethod() {
        return mMethod;
    }

    public boolean getFollowRedirect() {
        return mFollowRedirect;
    }

    public List<String> getCertificatePinningKeys() {
        return mCertificatePinningKeys;
    }


    public void setFollowRedirect(boolean follow) {
        mFollowRedirect = follow;
    }

    public int getTimeout() {
        return mTimeout;
    }

    public void setTimeout(int timeout) {
        mTimeout = timeout;
    }

    public ICallback getCallback() {
        return mCallback;
    }

    public void setCertificatePinningKeys(List<String> certificatePinningKeys) {
        mCertificatePinningKeys = certificatePinningKeys;
    }

    public void setCallback(ICallback callback) {
        this.mCallback = callback;
    }


}
